@@ -46,7 +46,7 @@ def format_setting_value(value):
     import json
     import logging
     formatted_value = value
-    if isinstance(value, str) and any([i in value for i in ['"', '[', '{']]):
+    if isinstance(value, str) and (any([i in value for i in ['"', '[', '{']]) or value.lower() in ['true', 'false']):
         try:
             formatted_value = json.loads(value)
         except json.JSONDecodeError as exc:
